#### Elasticsearch

用于快速使用 Elasticsearch 的帮助工具

| 函数名称         | 功能阐述             |
| ---------------- | -------------------- |
| index_refresh    | 刷新索引             |
| index_get        | 获取索引信息         |
| index_create     | 创建索引             |
| index_delete     | 删除索引             |
| index_exists     | 判断是否存在索引     |
| alias_get        | 获取索引别名信息     |
| alias_create     | 创建索引别名         |
| alias_delete     | 删除索引别名         |
| alias_exists     | 判断是否存在索引别名 |
| doc_get          | 获取文档完整内容     |
| doc_get_source   | 获取文档原始内容     |
| doc_create       | 创建文档             |
| doc_delete       | 删除文档             |
| doc_update       | 更新文档             |
| doc_replace      | 创建或更新文档       |
| doc_exists       | 判断是否存在文档     |
| doc_count        | 统计文档             |
| docs_bulk        | 批量操作文档         |
| docs_mget        | 批量获取文档         |
| def docs_reindex | 重建索引             |
| search           | 搜索索引             |
| scroll           | 滚动查询             |
| scroll_clear     | 清除滚动查询         |
| bulk             | 快速操作工具         |
| scan             | 滚动搜索工具         |

